pilot.api.data.api.DataUnit

Package pilot :: Package api :: Package data :: Module api :: Class DataUnit |

# Class DataUnit

source code

DataUnit (DU).

Holds a set of files (that generally share the same locality and are used together).

Instance Methods
cancel(self) Cancel the PD. | source code
export(self, target_directory) copies content of PD to a directory on the local machine | source code
get_state(self) get current state of Pilot Data:... | source code
wait(self) Wait until in Running state (or Failed state) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
| description
| file_list
| id
| state
Inherited from `object`: `__class__`

Method Details

### get_state(self) | source code
    get current state of Pilot Data:
        New => Initialized
        Pending => Files are synchronized with a pilot store
        Running => PD is in sync with all replicas
        Done => Terminated